@@ -48,3 +48,8 @@ def test_auth_hidden_password(clean_redis, cli):
     cli.send("auth hello-world")
     cli.expect("auth")
     cli.expect(r"\*{11}")
+
+
+def test_hello_command_is_not_supported(cli):
+    cli.sendline("hello 3")
+    cli.expect("IRedis currently not support RESP3")
